import * as __WEBPACK_EXTERNAL_MODULE_react_jsx_runtime__ from "react/jsx-runtime";
import * as __WEBPACK_EXTERNAL_MODULE_react__ from "react";
import * as __WEBPACK_EXTERNAL_MODULE_react_window__ from "react-window";
import * as __WEBPACK_EXTERNAL_MODULE_react_virtualized_auto_sizer__ from "react-virtualized-auto-sizer";
import * as __WEBPACK_EXTERNAL_MODULE_classnames__ from "classnames";
import * as __WEBPACK_EXTERNAL_MODULE_memoize_one__ from "memoize-one";
import * as __WEBPACK_EXTERNAL_MODULE_string_natural_compare__ from "string-natural-compare";
import * as __WEBPACK_EXTERNAL_MODULE__file_type_icon_index_js__ from "../file-type-icon/index.js";
import "./index.css";
const FILE_TYPES_ICON_MAP = {
    js: "js",
    jsx: "jsx",
    ts: "ts",
    tsx: "ts",
    json: "json",
    scss: "scss",
    css: "css",
    less: "less",
    tsconfig: "tsconfig",
    html: "html"
};
function getFileIcon(file) {
    const type = FILE_TYPES_ICON_MAP[(file || "").split(".").pop() || ""] || "text";
    return /*#__PURE__*/ (0, __WEBPACK_EXTERNAL_MODULE_react_jsx_runtime__.jsx)(__WEBPACK_EXTERNAL_MODULE__file_type_icon_index_js__.FileTypeIcon, {
        type: type
    });
}
const Row = /*#__PURE__*/ (0, __WEBPACK_EXTERNAL_MODULE_react__.memo)(({ data, index, style })=>{
    const { flattenedData, onOpen, onSelect, selectedKeys } = data;
    const node = flattenedData[index];
    const left = 20 * node.depth;
    return /*#__PURE__*/ (0, __WEBPACK_EXTERNAL_MODULE_react_jsx_runtime__.jsx)("div", {
        className: (0, __WEBPACK_EXTERNAL_MODULE_classnames__["default"])("tree-node", {
            "tree-node-selected": selectedKeys?.includes(node.id)
        }),
        style: style,
        onClick: ()=>onOpen(node),
        children: /*#__PURE__*/ (0, __WEBPACK_EXTERNAL_MODULE_react_jsx_runtime__.jsxs)("div", {
            className: (0, __WEBPACK_EXTERNAL_MODULE_classnames__["default"])("tree-item", {
                "tree-folder": node.folder,
                "tree-item-expanded": node.expanded,
                "tree-item-open": !node.expanded
            }),
            onClick: (e)=>onSelect(e, node),
            style: {
                left: `${left}px`,
                width: `calc(100% - ${left}px)`
            },
            children: [
                !node.folder && getFileIcon(node.label),
                /*#__PURE__*/ (0, __WEBPACK_EXTERNAL_MODULE_react_jsx_runtime__.jsx)("span", {
                    className: "label-name",
                    children: node.label
                })
            ]
        })
    });
}, __WEBPACK_EXTERNAL_MODULE_react_window__.areEqual);
const getItemData = (0, __WEBPACK_EXTERNAL_MODULE_memoize_one__["default"])((onOpen, onSelect, flattenedData, selectedKeys)=>({
        onOpen,
        onSelect,
        flattenedData,
        selectedKeys
    }));
const FileTree = (props)=>{
    const { modules, selectedKeys = [] } = props;
    const [openedNodeIds, setOpenedNodeIds] = (0, __WEBPACK_EXTERNAL_MODULE_react__.useState)([]);
    const onOpen = (node)=>{
        if (!node.folder) return;
        node.expanded ? setOpenedNodeIds(openedNodeIds.filter((id)=>id !== node.id)) : setOpenedNodeIds([
            ...openedNodeIds,
            node.id
        ]);
    };
    const onSelect = (e, node)=>{
        //e.stopPropagation();
        if (node.folder) return;
        console.log("---node", e, node);
        props.onSelect?.(node.id);
    };
    const flattenedData = createFlattenTree(modules, openedNodeIds);
    const itemData = getItemData(onOpen, onSelect, flattenedData, selectedKeys);
    return /*#__PURE__*/ (0, __WEBPACK_EXTERNAL_MODULE_react_jsx_runtime__.jsx)(__WEBPACK_EXTERNAL_MODULE_react_virtualized_auto_sizer__["default"], {
        children: ({ height, width })=>/*#__PURE__*/ (0, __WEBPACK_EXTERNAL_MODULE_react_jsx_runtime__.jsx)(__WEBPACK_EXTERNAL_MODULE_react_window__.FixedSizeList, {
                className: "code-file-tree",
                height: height,
                itemCount: flattenedData.length,
                itemSize: 22,
                width: width,
                itemKey: (index)=>flattenedData[index].id,
                itemData: itemData,
                children: Row
            })
    });
};
function createFlattenTree(data, expandedKeys) {
    const flatTree = [];
    const filePaths = Object.keys(data);
    // console.log(JSON.parse(JSON.stringify(filePaths)))
    // filePaths.sort((a, b) => {
    //   // 检查字符串a是否包含斜杠
    //   const hasSlashA = a.substring(1).lastIndexOf('/');
    //   // 检查字符串b是否包含斜杠
    //   const hasSlashB = b.substring(1).lastIndexOf('/');
    //   console.log('---a', hasSlashA)
    //   console.log('---b', hasSlashB)
    //   // 如果a包含斜杠，而b不包含，则a应该排在b之后
    //   if (hasSlashA > -1 && hasSlashB > -1) {
    //     return hasSlashB - hasSlashA;
    //   }
    //   return naturalCompare(a, b, {
    //     caseInsensitive: true,
    //   }); // 包含斜杠的字符串按字典顺序排序
    // });
    // console.log(filePaths)
    filePaths.forEach((key)=>{
        const parts = key.split("/");
        const fileNames = [];
        for(let i = 1; i <= parts.length; i++){
            const path = parts.slice(0, i).join("/");
            let expanded = expandedKeys.includes(path);
            if (path && !flatTree.some((node)=>node.id === path)) fileNames.push({
                id: path,
                label: parts[i - 1] || "/",
                folder: i < parts.length,
                depth: i - 1,
                expanded: expanded
            });
            if (expanded) break;
        }
        // console.log('--fileNames', fileNames);
        fileNames.sort((a, b)=>(0, __WEBPACK_EXTERNAL_MODULE_string_natural_compare__["default"])(a.id, b.id, {
                caseInsensitive: true
            }));
        flatTree.push(...fileNames);
    });
    return flatTree;
}
export { FileTree, createFlattenTree };
