import * as __WEBPACK_EXTERNAL_MODULE_react_jsx_runtime__ from "react/jsx-runtime";
import * as __WEBPACK_EXTERNAL_MODULE_react__ from "react";
import * as __WEBPACK_EXTERNAL_MODULE_antd__ from "antd";
import * as __WEBPACK_EXTERNAL_MODULE__gant_lowcode_lowcode_plugin_base_monaco_editor__ from "@gant-lowcode/lowcode-plugin-base-monaco-editor";
import "@gant-lowcode/lowcode-plugin-base-monaco-editor/lib/style.js";
import * as __WEBPACK_EXTERNAL_MODULE__file_tree_index_js__ from "../file-tree/index.js";
import "./index.css";
const DEBOUNCE_UPDATE_INTERVAL_IN_MS = 500;
function SourcesView({ code, onCodeChange }) {
    const editorContainerRef = (0, __WEBPACK_EXTERNAL_MODULE_react__.useRef)(null);
    const [state, setState] = (0, __WEBPACK_EXTERNAL_MODULE_react__.useState)(()=>{
        const allFiles = Object.values(code.modules);
        const currentFile = [
            allFiles.find((x)=>/pages.+(js|ts)x?$/.test(x.fpath)),
            allFiles.find((m)=>m.entry)
        ].filter(Boolean)[0];
        return {
            currentFile,
            selectedKeys: [
                currentFile?.fpath
            ]
        };
    });
    const [height, setHeight] = (0, __WEBPACK_EXTERNAL_MODULE_react__.useState)(0);
    (0, __WEBPACK_EXTERNAL_MODULE_react__.useEffect)(()=>{
        const observer = new ResizeObserver(()=>{
            if (editorContainerRef.current) {
                const { height } = editorContainerRef.current.getBoundingClientRect();
                setHeight(height - 2);
            }
        });
        if (editorContainerRef.current) observer.observe(editorContainerRef.current);
        return ()=>{
            if (editorContainerRef.current) observer.unobserve(editorContainerRef.current);
        };
    }, []);
    const ref = (0, __WEBPACK_EXTERNAL_MODULE_react__.useRef)({
        debounceTimer: null
    });
    const onSelect = (key)=>{
        setState((prev)=>{
            if (ref.current.debounceTimer) ref.current.debounceTimer = null;
            return {
                ...prev,
                currentFile: code.modules[key] || prev.currentFile
            };
        });
    };
    return /*#__PURE__*/ (0, __WEBPACK_EXTERNAL_MODULE_react_jsx_runtime__.jsxs)(__WEBPACK_EXTERNAL_MODULE_antd__.Splitter, {
        className: "sources-panes",
        children: [
            /*#__PURE__*/ (0, __WEBPACK_EXTERNAL_MODULE_react_jsx_runtime__.jsx)(__WEBPACK_EXTERNAL_MODULE_antd__.Splitter.Panel, {
                defaultSize: 300,
                min: 300,
                max: "70%",
                className: "file-tree-pane",
                children: /*#__PURE__*/ (0, __WEBPACK_EXTERNAL_MODULE_react_jsx_runtime__.jsx)(__WEBPACK_EXTERNAL_MODULE__file_tree_index_js__.FileTree, {
                    modules: code.modules,
                    onSelect: onSelect,
                    selectedKeys: state.currentFile?.fpath ? [
                        state.currentFile?.fpath
                    ] : void 0
                })
            }),
            /*#__PURE__*/ (0, __WEBPACK_EXTERNAL_MODULE_react_jsx_runtime__.jsx)(__WEBPACK_EXTERNAL_MODULE_antd__.Splitter.Panel, {
                className: "source-code-pane",
                children: /*#__PURE__*/ (0, __WEBPACK_EXTERNAL_MODULE_react_jsx_runtime__.jsx)("div", {
                    ref: editorContainerRef,
                    style: {
                        height: "100%"
                    },
                    children: /*#__PURE__*/ (0, __WEBPACK_EXTERNAL_MODULE_react_jsx_runtime__.jsx)(__WEBPACK_EXTERNAL_MODULE__gant_lowcode_lowcode_plugin_base_monaco_editor__["default"], {
                        height: height,
                        language: getFileLanguage(state.currentFile?.fpath),
                        saveViewState: true,
                        defaultValue: state.currentFile?.code,
                        path: state.currentFile?.fpath,
                        onChange: (value)=>{
                            console.debug("[monaco editor] onChange: %o (currentFile: %o)", {
                                value
                            }, state.currentFile);
                            const currentFile = state.currentFile;
                            if (currentFile) {
                                if (ref.current.debounceTimer) clearTimeout(ref.current.debounceTimer);
                                ref.current.debounceTimer = setTimeout(()=>{
                                    ref.current.debounceTimer = null;
                                    onCodeChange({
                                        ...code,
                                        modules: {
                                            ...code.modules,
                                            [currentFile.fpath]: {
                                                ...currentFile,
                                                code: value || ""
                                            }
                                        }
                                    });
                                }, DEBOUNCE_UPDATE_INTERVAL_IN_MS);
                            }
                        }
                    })
                })
            })
        ]
    });
}
function getFileLanguage(file) {
    switch((file || "").split(".").pop()){
        case "ts":
        case "tsx":
            return "typescript";
        case "js":
        case "jsx":
            return "javascript";
        case "css":
            return "css";
        case "scss":
            return "scss";
        case "less":
            return "less";
        case "json":
            return "json";
        case "md":
            return "markdown";
        default:
            return "text";
    }
}
export { SourcesView };
